"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TapeSession = void 0;
const zlib_1 = require("zlib");
class TapeSession {
    constructor() {
        this.records = [];
    }
    readFromServer(contents) {
        return __awaiter(this, void 0, void 0, function* () {
            // un-gzip and un-json the blob
            const uncompressed = (0, zlib_1.gunzipSync)(contents);
            const jsonPayload = JSON.parse(uncompressed.toString());
            // Un-base64 the bodies
            this.records = jsonPayload.map((record) => {
                return Object.assign(Object.assign({}, record), { request: Object.assign(Object.assign({}, record.request), { body: Buffer.from(record.request.body, 'base64') }), response: Object.assign(Object.assign({}, record.response), { body: Buffer.from(record.response.body, 'base64') }) });
            });
        });
    }
    toServer() {
        // Base64 the bodies
        const jsonPayload = this.records.map((record) => {
            return Object.assign(Object.assign({}, record), { request: Object.assign(Object.assign({}, record.request), { body: record.request.body.toString('base64') }), response: Object.assign(Object.assign({}, record.response), { body: record.response.body.toString('base64') }) });
        });
        // Json and gzip the blob
        const compressed = (0, zlib_1.gzipSync)(JSON.stringify(jsonPayload));
        return compressed;
    }
}
exports.TapeSession = TapeSession;
