"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const { default: Groove, CacheModeEnum } = require("../index");
const HttpsProxyAgent = require('https-proxy-agent');
const { request } = require("https");
const httpsFetchWithCertificate = (url, configuration) => __awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve, reject) => {
        request(url, configuration, (response) => {
            let data = "";
            response.on("data", (chunk) => {
                data = data + chunk.toString();
            });
            response.on("end", () => {
                resolve(data);
            });
            response.on("error", (error) => {
                reject(error);
            });
        }).end();
    });
});
describe('testing proxy client', () => {
    let proxy = null;
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        proxy = new Groove({});
        yield proxy.launch();
    }));
    afterAll(() => {
        proxy.stop();
    });
    test('tape should record and edit', () => __awaiter(void 0, void 0, void 0, function* () {
        yield proxy.setCacheMode(CacheModeEnum.OFF);
        yield proxy.tapeStart();
        var agent = new HttpsProxyAgent(proxy.baseUrlProxy);
        const contents = yield httpsFetchWithCertificate("https://freeman.vc", {
            agent,
            ca: proxy.certificate,
        });
        expect(contents.length).toBeGreaterThanOrEqual(100);
        yield proxy.tapeStop();
        const tape = yield proxy.tapeGet();
        tape.records[0].response.body = Buffer.from("Hello world");
        yield proxy.tapeLoad(tape);
        const contentsUpdated = yield httpsFetchWithCertificate("https://freeman.vc", {
            agent,
            ca: proxy.certificate,
        });
        expect(contentsUpdated).toBe("Hello world");
    }));
});
