"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.streamToBuffer = exports.sleep = exports.fetchWithTimeout = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
const fetchWithTimeout = (url, options) => __awaiter(void 0, void 0, void 0, function* () {
    const { timeout } = options;
    const controller = new AbortController();
    const id = setTimeout(() => controller.abort(), timeout);
    const response = yield (0, node_fetch_1.default)(url, Object.assign(Object.assign({}, options), { 
        //signal: controller.signal,
        // Non-standard timeout parameter specified in node-fetch
        // We use this instead of the signal because the 2.x.x signal type definitions
        // are incompatible. They were fixed in 3.x but 3.x also brought along ESM only requirements
        // that we don't currently use.
        timeout }));
    clearTimeout(id);
    return response;
});
exports.fetchWithTimeout = fetchWithTimeout;
const sleep = (ms) => {
    return new Promise(resolve => setTimeout(resolve, ms));
};
exports.sleep = sleep;
const streamToBuffer = (stream) => {
    // Right now we can't typehint the stream because node's built-in ReadableStream
    // typehint is missing `.on` properties
    return new Promise((resolve, reject) => {
        const _buf = [];
        stream.on("data", (chunk) => _buf.push(chunk));
        stream.on("end", () => resolve(Buffer.concat(_buf)));
        stream.on("error", (err) => reject(err));
    });
};
exports.streamToBuffer = streamToBuffer;
